@@ -10,10 +10,13 @@
 #ifndef __CONFIG_FILE_H
 #define __CONFIG_FILE_H
 
-#include "detox.h"
+#include "detox_struct.h"
 
 extern int config_file_lineno;
 
-extern struct detox_parse_results *parse_config_file(char *filename, struct detox_parse_results *previous_list, struct detox_options *main_options);
+extern config_file_t *config_file_init(void);
+extern config_file_t *config_file_load(options_t *main_options);
 
-#endif				/* __CONFIG_FILE_H */
+extern config_file_t *parse_config_file(char *filename, config_file_t *previous_list, options_t *main_options);
+
+#endif /* __CONFIG_FILE_H */
