@@ -11,8 +11,8 @@
 #ifndef __PARSE_TABLE_H
 #define __PARSE_TABLE_H
 
-#include "table.h"
+#include "detox_struct.h"
 
-extern struct translation_table *parse_table(char *filename);
+extern table_t *parse_table(char *filename);
 
-#endif				/* __PARSE_TABLE_H */
+#endif /* __PARSE_TABLE_H */
